function [Theat,Thin,Thm,Tcm,Thout]=steady(in,Param)
%
%    This function calculates the steady state values of all the temperatures in the heat exchanger
%
Tin=in(1);
Fhin=in(2);
Qin=in(3);
Fcin=in(4);
%
tstep=Param(1);
Cpw=Param(2);
rhow=Param(3);
Cpheat=Param(4);
Mheat=Param(5);
rhoheat=Param(6);
Uheat=Param(7);
Upipe=Param(8);
oDodpipe=Param(9);
iDodpipe=Param(10);
oDidpipe=Param(11);
iDidpipe=Param(12);
Lpipe=Param(13);
oDhpipe=Param(14);
iDhpipe=Param(15);
Dheat=Param(16);
Lheat=Param(17);
%
%   Definitions of often used parameters with conversion factors
%
%	 Calculation of the steady state temperature distribution
%
%	 the heater
%
%
%	 Double pipe heat exchanger steady state
HW=rhow*Cpw*Fhin*(4.184*3785/60); % HW is in units of W/deg C
CW=rhow*Cpw*Fcin*(4.184*3785/60); % CW is in units of W/deg C
PIPE=Upipe*pi*iDidpipe*Lpipe/5*(2.54^2/10); % PIPE is in units of W/deg C
VHC=rhow*(Cpw*4.184)*(Lpipe/5)*pi*(0.5*iDidpipe)^2*(2.54^3); % VHC is in units of J/deg C
VCC=rhow*(Cpw*4.184)*(Lpipe/5)*pi*((0.5*iDodpipe)^2-(0.5*oDidpipe)^2)*(2.54^3); % VCC is in units of J/deg C

%
% Initialize all temp
%
Thm=[20 20 20 20 20];Tcm=[20 20 20 20 20];Theat=20;Thin=20;
%   The calculation over the heater
%
%
%
% initial guesses for temperatures
%   The calculation for the pipe compartments
%
% March forward in time to steady state
%
for time= 1:400;
dH=Uheat*pi*Dheat*Lheat*(2.54^2/10)*0.5*(2*Theat-Thin-Tin); % dH is in units of W
T_heat=Theat+(tstep/(Mheat*Cpheat*4.184))*(Qin-dH);
T_hin=dH/HW+Tin;
% Compartment 1
dH1=PIPE*(Thm(1)-Tcm(1)); % dH1 is in units of W
T_hm(1)=Thm(1)+(tstep/VHC)*(HW*(Thin-Thm(1))-dH1);
T_cm(1)=Tcm(1)+(tstep/VCC)*(CW*(Tcm(2)-Tcm(1))+dH1);
%
% for compartments 2 through 4
for i=2:4,
   dHi=PIPE*(Thm(i)-Tcm(i)); % dHi is in units of W
   T_hm(i)=Thm(i)+(tstep/VHC)*(HW*(Thm(i-1)-Thm(i))-dHi);
   T_cm(i)=Tcm(i)+(tstep/VCC)*(CW*(Tcm(i+1)-Tcm(i))+dHi);
end
%
% for compartment 5
dH5=PIPE*(Thm(5)-Tcm(5)); % dH5 is in units of W
T_hm(5)=Thm(5)+(tstep/VHC)*(HW*(Thm(4)-Thm(5))-dH5);
T_cm(5)=Tcm(5)+(tstep/VCC)*(CW*(Tin-Tcm(5))+dH5);
T_hout=T_hm(5);
Thm=T_hm;Tcm=T_cm;Theat=T_heat;Thin=T_hin;Thout=T_hout;
end

%*********************************
