function [Theat,Thin,Thm,Tcm,Thout]=steady(in,Param)
%
%    This function calculates the steady state values of all the temperatures in the heat exchanger
%
Tin=in(1);
Fhin=in(2);
Qin=in(3);
Fcin=in(4);
%
tstep=Param(1);
Cpw=Param(2);
rhow=Param(3);
Cpheat=Param(4);
Mheat=Param(5);
rhoheat=Param(6);
Uheat=Param(7);
Upipe=Param(8);
oDodpipe=Param(9);
iDodpipe=Param(10);
oDidpipe=Param(11);
iDidpipe=Param(12);
Lpipe=Param(13);
oDhpipe=Param(14);
iDhpipe=Param(15);
Dheat=Param(16);
Lheat=Param(17);
%
%   Definitions of often used parameters with conversion factors
%
HW=rhow*Cpw*Fhin*(4.184*3785/60); % HW is in units of W/deg C
CW=rhow*Cpw*Fcin*(4.184*3785/60); % CW is in units of W/deg C
PIPE=Upipe*pi*iDidpipe*Lpipe*(2.54^2/10); % PIPE is in units of W/deg C
%
%	 Calculation of the steady state temperature distribution
%
%	 the heater
%
Thin=Qin/HW+Tin;
Theat=Qin/(Uheat*pi*Dheat*Lheat)*(10/2.54^2)+0.5*(Thin+Tin);
%
%	 Double pipe heat exchanger steady state
%	 Initial guess of q
eps=1.0;
epsT=0.00001;
%
qold=PIPE;
if Fcin==Fhin
   qnew=PIPE*(Thin-qold/HW-Tin);
else
   qnew=PIPE*(qold*(1/HW-1/CW))/log((Thin-qold/CW-Tin)/(Thin-qold/HW-Tin));
end
while abs(qnew-qold)>eps
   q2=qold+(qnew-qold)/2;
   qold=q2;
   if Fcin==Fhin
      qnew=PIPE*(Thin-qold/HW-Tin);
   else
      qnew=PIPE*(qold*(1/HW-1/CW))/log((Thin-qold/CW-Tin)/(Thin-qold/HW-Tin));
   end
end
%
%	 Calculate guess of Tc1
%
Tcm(1)=qnew/CW+Tin;
diffT=epsT+1;
%
while abs(diffT)>epsT
   %
   %	 balance over compartment 1
  %
   Thm(1)=(HW*Thin+PIPE/5*Tcm(1))/(HW+PIPE/5);
   Tcm(2)=Tcm(1)-PIPE/5*(Thm(1)-Tcm(1))/CW;
   %
   %	 balance over 2 through 4 compartments
   %
   for i=2:4,
      Thm(i)=(HW*Thm(i-1)+PIPE/5*Tcm(i))/(HW+PIPE/5);

     Tcm(i+1)=Tcm(i)-PIPE/5*(Thm(i)-Tcm(i))/CW;
   end
   %
   %	 balance over the last compartment
   %
   Thm(5)=(HW*Thm(4)+PIPE/5*Tcm(5))/(HW+PIPE/5);

 Thout=Thm(5);
   tcm_last=Tcm(5)-PIPE/5*(Thm(5)-Tcm(5))/CW;

   %
   %	 check to make sure that tcm_last is close to Tin then if not, update guess, and calculate T's again
   %   it only updates the guess if the loop needs to iterate again
   %
   diffT=tcm_last-Tin;
   if abs(diffT)>epsT
      Tnew=Tcm(1)-0.5*diffT;
      Tcm(1)=Tnew;
   end
end